@@ -11,6 +11,8 @@ from ._hyperelasticity_isotropic import (
     third_order_deformation,
     ogden,
     arruda_boyce,
+    extended_tube,
+    van_der_waals,
 )
 
 from ._hyperelasticity_anisotropic import (
