@@ -14,26 +14,19 @@ def test_fiber():
 
     for model in [fiber, fiber_family]:
 
-        # init Material
+        # init Material without bulk
         M = MaterialHyperelastic(model, E=1, angle=30, axis=2)
 
+        # init Material
+        M = MaterialHyperelastic(model, E=1, angle=30, axis=2, bulk=5000)
+
         W0 = M.function([FF])
         dW = M.gradient([FF])
         DW = M.hessian([FF])
 
         assert W0[0].shape == (2,)
-        assert dW[0].shape == (
-            3,
-            3,
-            2,
-        )
-        assert DW[0].shape == (
-            3,
-            3,
-            3,
-            3,
-            2,
-        )
+        assert dW[0].shape == (3, 3, 2,)
+        assert DW[0].shape == (3, 3, 3, 3, 2,)
 
 
 def test_hgo():
@@ -45,28 +38,30 @@ def test_hgo():
 
     for model in [holzapfel_gasser_ogden]:
 
-        # init Material
+        # init Material without bulk
         M = MaterialHyperelastic(
             model, c=0.0764, k1=996.6, k2=524.6, kappa=0.2, angle=49.98, axis=2
         )
 
+        # init Material
+        M = MaterialHyperelastic(
+            model,
+            c=0.0764,
+            k1=996.6,
+            k2=524.6,
+            kappa=0.2,
+            angle=49.98,
+            axis=2,
+            bulk=5000,
+        )
+
         W0 = M.function([FF])
         dW = M.gradient([FF])
         DW = M.hessian([FF])
 
         assert W0[0].shape == (2,)
-        assert dW[0].shape == (
-            3,
-            3,
-            2,
-        )
-        assert DW[0].shape == (
-            3,
-            3,
-            3,
-            3,
-            2,
-        )
+        assert dW[0].shape == (3, 3, 2,)
+        assert DW[0].shape == (3, 3, 3, 3, 2,)
 
 
 if __name__ == "__main__":
